@@ -46,23 +46,22 @@
 #include "widgets/toolbars/kpToolToolBar.h"
 #include "lgpl/generic/kpUrlFormatter.h"
 
-#include <math.h>
 
 #include "kpLogCategories.h"
 #include <kio/netaccess.h> // kdelibs4support
 #include <KLocalizedString>
 
-#include <qcolor.h>
-#include <qbitmap.h>
-#include <qbrush.h>
-#include <qfile.h>
-#include <qimage.h>
-#include <qlist.h>
+#include <QColor>
+#include <QBitmap>
+#include <QBrush>
+#include <QFile>
 #include <QImage>
-#include <qpainter.h>
-#include <qrect.h>
-#include <qsize.h>
-#include <qmatrix.h>
+#include <QList>
+#include <QImage>
+#include <QPainter>
+#include <QRect>
+#include <QSize>
+#include <QTransform>
 
 //---------------------------------------------------------------------
 
@@ -149,11 +148,13 @@ void kpDocument::setURL (const QUrl &url, bool isFromURL)
 // public
 bool kpDocument::isFromURL (bool checkURLStillExists) const
 {
-    if (!m_isFromURL)
+    if (!m_isFromURL) {
         return false;
+    }
 
-    if (!checkURLStillExists)
+    if (!checkURLStillExists) {
         return true;
+    }
 
     return (!m_url.isEmpty () &&
             KIO::NetAccess::exists (m_url, KIO::NetAccess::SourceSide/*open*/,
@@ -216,13 +217,15 @@ void kpDocument::setMetaInfo (const kpDocumentMetaInfo &metaInfo)
 
 void kpDocument::setModified (bool yes)
 {
-    if (yes == m_modified)
+    if (yes == m_modified) {
         return;
+    }
 
     m_modified = yes;
 
-    if (yes)
+    if (yes) {
         emit documentModified ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -250,10 +253,7 @@ int kpDocument::constructorWidth () const
 
 int kpDocument::width (bool ofSelection) const
 {
-    if (ofSelection && m_selection)
-        return m_selection->width ();
-    else
-        return m_image->width ();
+    return (ofSelection && m_selection) ? m_selection->width() : m_image->width();
 }
 
 //---------------------------------------------------------------------
@@ -281,10 +281,7 @@ int kpDocument::constructorHeight () const
 
 int kpDocument::height (bool ofSelection) const
 {
-    if (ofSelection && m_selection)
-        return m_selection->height ();
-    else
-        return m_image->height ();
+    return (ofSelection && m_selection) ? m_selection->height() : m_image->height();
 }
 
 //---------------------------------------------------------------------
@@ -305,10 +302,7 @@ void kpDocument::setHeight (int h, const kpColor &backgroundColor)
 
 QRect kpDocument::rect (bool ofSelection) const
 {
-    if (ofSelection && m_selection)
-        return m_selection->boundingRect ();
-    else
-        return m_image->rect ();
+    return (ofSelection && m_selection) ? m_selection->boundingRect() : m_image->rect();
 }
 
 //---------------------------------------------------------------------
@@ -329,8 +323,7 @@ void kpDocument::setImageAt (const kpImage &image, const QPoint &at)
                << image.width ()
                << ",h=" << image.height ()
                << "), x=" << at.x ()
-               << ",y=" << at.y ()
-               << endl;
+               << ",y=" << at.y ();
 #endif
 
     kpPixmapFX::setPixmapAt (m_image, at, image);
@@ -351,8 +344,9 @@ kpImage kpDocument::image (bool ofSelection) const
 
         ret = imageSel->baseImage ();
     }
-    else
+    else {
         ret = *m_image;
+    }
 
     return ret;
 }
@@ -370,14 +364,17 @@ kpImage *kpDocument::imagePointer () const
 // public
 void kpDocument::setImage (const kpImage &image)
 {
-    m_oldWidth = width (), m_oldHeight = height ();
+    m_oldWidth = width ();
+    m_oldHeight = height ();
 
     *m_image = image;
 
-    if (m_oldWidth == width () && m_oldHeight == height ())
+    if (m_oldWidth == width () && m_oldHeight == height ()) {
         slotContentsChanged (image.rect ());
-    else
-        slotSizeChanged (width (), height ());
+    }
+    else {
+        slotSizeChanged (QSize (width (), height ()));
+    }
 }
 
 //---------------------------------------------------------------------
@@ -394,8 +391,9 @@ void kpDocument::setImage (bool ofSelection, const kpImage &image)
 
         imageSel->setBaseImage (image);
     }
-    else
+    else {
         setImage (image);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -418,20 +416,21 @@ void kpDocument::resize (int w, int h, const kpColor &backgroundColor)
     qCDebug(kpLogDocument) << "kpDocument::resize (" << w << "," << h << ")";
 #endif
 
-    m_oldWidth = width (), m_oldHeight = height ();
+    m_oldWidth = width ();
+    m_oldHeight = height ();
 
 #if DEBUG_KP_DOCUMENT && 1
     qCDebug(kpLogDocument) << "\toldWidth=" << m_oldWidth
-               << " oldHeight=" << m_oldHeight
-               << endl;
+               << " oldHeight=" << m_oldHeight;
 #endif
 
-    if (w == m_oldWidth && h == m_oldHeight)
+    if (w == m_oldWidth && h == m_oldHeight) {
         return;
+    }
 
     kpPixmapFX::resize (m_image, w, h, backgroundColor);
 
-    slotSizeChanged (width (), height ());
+    slotSizeChanged (QSize (width (), height ()));
 }
 
 //---------------------------------------------------------------------
@@ -444,18 +443,11 @@ void kpDocument::slotContentsChanged (const QRect &rect)
 
 //---------------------------------------------------------------------
 
-void kpDocument::slotSizeChanged (int newWidth, int newHeight)
-{
-    setModified ();
-    emit sizeChanged (newWidth, newHeight);
-    emit sizeChanged (QSize (newWidth, newHeight));
-}
-
-//---------------------------------------------------------------------
-
 void kpDocument::slotSizeChanged (const QSize &newSize)
 {
-    slotSizeChanged (newSize.width (), newSize.height ());
+    setModified ();
+    emit sizeChanged (newSize.width(), newSize.height());
+    emit sizeChanged (newSize);
 }
 
 //---------------------------------------------------------------------
