@@ -46,14 +46,14 @@ int main(int argc, char *argv [])
 
   KAboutData aboutData
   (
-    "kolourpaint",
+    QStringLiteral("kolourpaint"),
     i18n("KolourPaint"),
     QStringLiteral(KOLOURPAINT_VERSION_STRING),
     i18n("Paint Program by KDE"),
     KAboutLicense::Custom,
     QString(), // copyright statement - see license instead
     QString(), // other text
-    QLatin1String("http://www.kolourpaint.org/")   // home page
+    QStringLiteral("http://www.kolourpaint.org/")   // home page
   );
 
   // (this is _not_ the same as KAboutLicense::BSD)
@@ -63,32 +63,32 @@ int main(int argc, char *argv [])
   // Please add yourself here if you feel you're missing.
   // SYNC: with AUTHORS
 
-  aboutData.addAuthor(i18n("Clarence Dang"), i18n("Project Founder"), QLatin1String("dang@kde.org"));
+  aboutData.addAuthor(i18n("Clarence Dang"), i18n("Project Founder"), QStringLiteral("dang@kde.org"));
 
   aboutData.addAuthor(i18n("Thurston Dang"), i18n("Chief Investigator"),
-                      QLatin1String("thurston_dang@users.sourceforge.net"));
+                      QStringLiteral("thurston_dang@users.sourceforge.net"));
 
   aboutData.addAuthor(i18n("Martin Koller"), i18n("Scanning Support, Alpha Support, Current Maintainer"),
-                      QLatin1String("kollix@aon.at"));
+                      QStringLiteral("kollix@aon.at"));
 
-  aboutData.addAuthor(i18n("Kristof Borrey"), i18n("Icons"), QLatin1String("borrey@kde.org"));
-  aboutData.addAuthor(i18n("Tasuku Suzuki"), i18n("InputMethod Support"), QLatin1String("stasuku@gmail.com"));
-  aboutData.addAuthor(i18n("Kazuki Ohta"), i18n("InputMethod Support"), QLatin1String("mover@hct.zaq.ne.jp"));
-  aboutData.addAuthor(i18n("Nuno Pinheiro"), i18n("Icons"), QLatin1String("nf.pinheiro@gmail.com"));
-  aboutData.addAuthor(i18n("Danny Allen"), i18n("Icons"), QLatin1String("dannya40uk@yahoo.co.uk"));
-  aboutData.addAuthor(i18n("Mike Gashler"), i18n("Image Effects"), QLatin1String("gashlerm@yahoo.com"));
+  aboutData.addAuthor(i18n("Kristof Borrey"), i18n("Icons"), QStringLiteral("borrey@kde.org"));
+  aboutData.addAuthor(i18n("Tasuku Suzuki"), i18n("InputMethod Support"), QStringLiteral("stasuku@gmail.com"));
+  aboutData.addAuthor(i18n("Kazuki Ohta"), i18n("InputMethod Support"), QStringLiteral("mover@hct.zaq.ne.jp"));
+  aboutData.addAuthor(i18n("Nuno Pinheiro"), i18n("Icons"), QStringLiteral("nf.pinheiro@gmail.com"));
+  aboutData.addAuthor(i18n("Danny Allen"), i18n("Icons"), QStringLiteral("dannya40uk@yahoo.co.uk"));
+  aboutData.addAuthor(i18n("Mike Gashler"), i18n("Image Effects"), QStringLiteral("gashlerm@yahoo.com"));
 
-  aboutData.addAuthor(i18n("Laurent Montel"), i18n("KDE 4 Porting"), QLatin1String("montel@kde.org"));
-  aboutData.addAuthor(i18n("Christoph Feck"), i18n("KF 5 Porting"), QLatin1String("cfeck@kde.org"));
+  aboutData.addAuthor(i18n("Laurent Montel"), i18n("KDE 4 Porting"), QStringLiteral("montel@kde.org"));
+  aboutData.addAuthor(i18n("Christoph Feck"), i18n("KF 5 Porting"), QStringLiteral("cfeck@kde.org"));
 
   aboutData.addCredit(i18n("Thanks to the many others who have helped to make this program possible."));
 
   QCommandLineParser cmdLine;
   KAboutData::setApplicationData(aboutData);
-  QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kolourpaint"), app.windowIcon()));
+  QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kolourpaint"), QApplication::windowIcon()));
   cmdLine.addVersionOption();
   cmdLine.addHelpOption();
-  cmdLine.addPositionalArgument("files", i18n("Image files to open, optionally"), "[files...]");
+  cmdLine.addPositionalArgument(QStringLiteral("files"), i18n("Image files to open, optionally"), QStringLiteral("[files...]"));
 
   aboutData.setupCommandLine(&cmdLine);
   cmdLine.process(app);
@@ -120,5 +120,5 @@ int main(int argc, char *argv [])
     }
   }
 
-  return app.exec();
+  return QApplication::exec();
 }
